@@ -853,7 +853,7 @@ class SBtabTable():
 
         return True
     
-    def to_data_frame(self):
+    def to_data_frame(self, rba=False):
         '''
         Exports SBtab table object as pandas dataframe.
 
@@ -864,7 +864,8 @@ class SBtabTable():
             import pandas as pd
             rows = self._get_rows()
             n_cols = max(map(len, rows))
-            column_names = list(map(lambda s: s[1:], self.columns))
+            if rba: column_names = list(map(lambda s: s, self.columns))
+            else: column_names = list(map(lambda s: s[1:], self.columns))
             while len(column_names) < n_cols:
                 column_names += ['Col%d' % len(column_names)]
             df = pd.DataFrame(data=self._get_rows(), columns=column_names)
